BernoulliNegativeSampler
========================

.. currentmodule:: pykeen.sampling

.. autoclass:: BernoulliNegativeSampler
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~BernoulliNegativeSampler.corrupt_batch

   .. rubric:: Methods Documentation

   .. automethod:: corrupt_batch
